#pragma once
/*++

Copyright (c) Pico Systems Co., Ltd.

Module Name: gpio_dll.h

Abstract:

	Support Library for GPIO-MIF-01
	GPIO Dynamic Link library definitions

Revision History:

	1/May/2020   Created by Makoto Ito

--*/
#pragma once  

#include "windows.h"


// The following ifdef block is the standard way of creating macros
// which make exporting from a DLL simpler.

#ifdef GPIO_DLL_EXPORTS
#define GPIO_API __declspec(dllexport)   
#else  
#define GPIO_API __declspec(dllimport)   
#endif  

// Type Definition

typedef HANDLE	GPIO_HANDLE;
typedef ULONG	GPIO_STATUS;

// Device status

enum
{
	GPIO_OK,
	GPIO_INVALID_HANDLE,
	GPIO_COMMAND_ERROR,
	GPIO_IO_ERROR,
	GPIO_TIMEOUT,
	GPIO_BUSY,
	GPIO_OTHER_ERROR,
	GPIO_H_LEVEL,
	GPIO_L_LEVEL
};

// Etc.

#define STX			0x02
#define ETX			0x03
#define CR			0x0D
#define ESC			0x7D
#define ESC_STX		0xE2
#define ESC_ETX		0xE3
#define ESC_ESC		0x5D

#define HOST_ADRES	0x00
#define GPIO_ADRES	0x40

#define MAX_GPIO_PACKET_SIZE	36

// Functions to Export

GPIO_API
GPIO_STATUS WINAPI GPIO_ScanInterface
(
	LPSTR psComPort
);

GPIO_API
GPIO_STATUS WINAPI GPIO_OpenInterface
(
	LPSTR psComPort,
	GPIO_HANDLE* mdbIfHandle
);

GPIO_API
GPIO_STATUS WINAPI GPIO_CloseInterface
(
	GPIO_HANDLE mdbIfHandle
);

GPIO_API
GPIO_STATUS WINAPI GPIO_Input
(
	GPIO_HANDLE gpioHandle,
	char cPort,
	unsigned char* pucData
);

GPIO_API
GPIO_STATUS WINAPI GPIO_Output
(
	GPIO_HANDLE gpioHandle,
	char cPort,
	unsigned char ucData
);

GPIO_API
GPIO_STATUS WINAPI GPIO_BitTest
(
	GPIO_HANDLE gpioHandle,
	char cPort,
	unsigned char ucBit
);

GPIO_API
GPIO_STATUS WINAPI GPIO_BitSet
(
	GPIO_HANDLE gpioHandle,
	char cPort,
	unsigned char ucBit
);

GPIO_API
GPIO_STATUS WINAPI GPIO_BitReset
(
	GPIO_HANDLE gpioHandle,
	char cPort,
	unsigned char ucBit
);

GPIO_API
GPIO_STATUS WINAPI GPIO_GetVersion
(
	GPIO_HANDLE mdbIfHandle,
	unsigned char* pucBuffer,
	unsigned int uiBufferSize
);
